local addonName, addonTable = ...;

local Variables = addonTable.Variables;

addonTable.Functions = {};
addonTable.Functions["Default"] = addonTable.Common.Functions;
addonTable.Functions["ScrollFrame"] = {};

addonTable.Functions["ScrollFrame"] = {

	-- Find out what Anchor Value to use
	UseAnchor = function()
		local anchor;
		anchor = Variables["Default"].MainAnchor;
		if ( Variables["ScrollFrame"].MultipleAnchors ) then
			if ( Variables["ScrollFrame"].Collapsed ) then
				anchor = Variables["ScrollFrame"].CollapsedAnchor;
			else
				anchor = Variables["ScrollFrame"].ExpandedAnchor;
			end
		end
		return anchor;
	end,

	-- Set the Anchor to the Frame
	SetAnchor = function(self)
		if ( not self ) then return; end
		local anchor = addonTable.Functions["ScrollFrame"].UseAnchor();
		local offset = anchor.Offset;
		local pos = { pt = "TOPLEFT", a = UIParent, apt = "BOTTOMLEFT", x = offset.Left, y = offset.Top };
		if ( offset.Left == 0 and offset.Top == 0 ) then
			pos = { pt = "CENTER", a = UIParent, apt = "CENTER", x = offset.Left, y = offset.Top };
		end
		self:SetPoint(pos.pt, pos.a, pos.apt, pos.x, pos.y);
	end,
	
	-- Get the Anchor to the Frame
	StoreAnchor = function(self)
		if ( not self ) then return; end
		local anchor = addonTable.Functions["ScrollFrame"].UseAnchor();
		anchor.Offset.Top = self:GetTop();
		anchor.Offset.Left = self:GetLeft();
		local offset = anchor.Offset;
		local pos = { pt = "TOPLEFT", a = UIParent, apt = "BOTTOMLEFT", x = offset.Left, y = offset.Top };
		if ( offset.Left == 0 and offset.Top == 0 ) then
			pos = { pt = "CENTER", a = UIParent, apt = "CENTER", x = offset.Left, y = offset.Top };
		end
	end,
	
	-- Handle OnMouseUp Event for the frame
	OnMouseUp = function(self)
		addonTable.Functions["Default"].OnMouseUp(self); 
		if ( self.hasMoved ) then
			addonTable.Functions["ScrollFrame"].StoreAnchor(self);
		end
	end,
	
	---------------------------------------------------------------------
	-- [v1.01.00] Additional Functionality if you collapse the WatchFrame
	---------------------------------------------------------------------
	Collapse = function(self,Clone)
		if ( Clone ) then	
			Clone:SetHeight( 40 );
			Clone.Child:SetHeight( 2 );
			Clone.ScrollBar:Hide();
			Variables["ScrollFrame"].Collapsed = WatchFrame.collapsed;
			Clone:ClearAllPoints();
			addonTable.Functions["ScrollFrame"].SetAnchor(Clone);
		end
	end,

	---------------------------------------------------------------------
	-- [v1.01.00] Additional Functionality if you expand the WatchFrame
	---------------------------------------------------------------------
	Expand = function(self,Clone)
		if ( Clone ) then		
			Clone:SetHeight( Variables["Default"].Size.Height);
			Clone.Child:SetHeight( Variables["ScrollFrame"].ScrollSize );
			Clone.ScrollBar:Show();
			Variables["ScrollFrame"].Collapsed = WatchFrame.collapsed;
			Clone:ClearAllPoints();
			addonTable.Functions["ScrollFrame"].SetAnchor(Clone);
		end
	end,
	
	
	
};
