﻿local addonName, addonTable = ...;

-- Localised data
local Functions = addonTable.Functions;
local Variables = addonTable.Variables;
local Translate = addonTable.Localization;

-- Localised Functions
local OnMouseDown 		= Functions["Default"].OnMouseDown;
local OnHide 			= Functions["Default"].OnHide;
local SetBackDrop 		= Functions["Default"].SetBackDrop;
local SetSize 			= Functions["Default"].SetSize;
local SetMovable 		= Functions["Default"].SetMovable;
local OnMouseUp 		= Functions["ScrollFrame"].OnMouseUp;
local SetAnchor 		= Functions["ScrollFrame"].SetAnchor;
local StoreAnchor 		= Functions["ScrollFrame"].StoreAnchor;

-- nUI Specific 
local nUI_Loaded 	= Variables["nUI"].Loaded;

-- Change this to flag up the main InfoPanel flag throughout the addon
addonTable.Variables["nUI"].InfoPanel = true;
local nUI_InfoPanel = addonTable.Variables["nUI"].InfoPanel;

-- Change this to flag up whether to track more than one anchor or not throughout the addon
addonTable.Variables["ScrollFrame"].MultipleAnchors = true;
local MultipleAnchors = addonTable.Variables["ScrollFrame"].MultipleAnchors;

-- The frames we will use 
local SWF_EventFrame;
local SWF_WatchFrame;
local SWF_InfoPanel;

---------------------------------------------------------------------------
-- [v1.01.00] Hook into the Collapse and Expand functions of the WatchFrame
---------------------------------------------------------------------------
hooksecurefunc( "WatchFrame_Collapse", function(self) Functions["ScrollFrame"].Collapse(self,SWF_WatchFrame); end);
hooksecurefunc( "WatchFrame_Expand", function(self) Functions["ScrollFrame"].Expand(self,SWF_WatchFrame); end);

-- Reset the default WatchFrame so that we have control
local function ResetWatchFrame(parent)

	local f = WatchFrame;
	local t = WatchFrameTitle;
	local b = WatchFrameCollapseExpandButton;
		
	if ( nUI_Loaded ) then
		nUI_Movers:lockFrame( WatchFrame, false, nil ); 
		nUI_Options.movedWatchFrame = true;
	end

	f:ClearAllPoints();
	f:SetClampedToScreen( false );
	f:SetParent(parent);
	f:SetWidth( parent:GetWidth() - 27.5 );
	f:SetPoint( "TOPLEFT", 27.5, 0 );
	f:SetPoint( "BOTTOMRIGHT", 0, 0 );
		
	f.ClearAllPoints = function() end;
	f.SetPoint = function() end;
	f.SetAllPoints = function() end;
		
	-- Handle the Title
	t:SetParent(parent)
	t.Hide = function() end
		
	-- Handle the Collapse/Expand Button
	b:SetParent(parent)
	b.Hide = function() end
	
	Variables["ScrollFrame"].Collapsed = WatchFrame.collapsed;
		
end

-- Create the Scrollable Frame
local function CreateScrollFrame()
	
	if ( nUI_Loaded ) then
		nUI_Movers:lockFrame( WatchFrame, false, nil );
		nUI_Options.movedWatchFrame = true;
	end

	-- Create the main Container.  This will be the movable frame
	local f = CreateFrame( "Frame", "SWF_WatchFrame",UIParent);
	f:SetClampedToScreen(true);
	f:SetFrameStrata("HIGH");

	Functions["Default"].SetSize(f,Variables["Default"].Size);
	Functions["Default"].SetBackDrop(f,Variables["Default"].BackGround);
	Functions["Default"].SetMovable(f,not Variables["Default"].Locked);
	Functions["ScrollFrame"].SetAnchor(f);
    f:SetScript("OnMouseUp", Functions["ScrollFrame"].OnMouseUp);
	
	-- Create the ScrollFrame to handle scrolling of contents    
	local s = CreateFrame( "ScrollFrame", "SWF_ScrollFrame", f, "UIPanelScrollFrameTemplate" );
    s:SetWidth( f:GetWidth() - 35 );
	s:SetPoint( "TOPLEFT", 5, -7.5 );
	s:SetPoint( "BOTTOMRIGHT", -30, 7.5 );
	f.Scroll = s;
	f.ScrollBar = _G[s:GetName() .. "ScrollBar"];
    
    local c = CreateFrame( "Frame", "SWF_ScrollChild", s );
	c:SetHeight( Variables["ScrollFrame"].ScrollSize );
    c:SetWidth( s:GetWidth() );
    c:SetAllPoints( s );
	f.Child = c;
	ResetWatchFrame( c );
    s:SetScrollChild( c );
	
	Functions["ScrollFrame"].StoreAnchor(f);
            
    return f;
end

-- If this is going to be an infopanel then set up the pre data
if ( nUI_InfoPanel ) then

	-- Check if nUI itself is loaded
	if ( IsAddOnLoaded("nUI") ) then
		nUI_Loaded = true;
	end
	
	-- If no nUI then the infopanel is useless.  But keep the flag for when it is available
	if ( nUI_Loaded ) then 
		
		-- No InfoPanels found yet?  Create the table ready for use then
		if not nUI_InfoPanels then nUI_InfoPanels = {}; end
		
		-- Set Up the Panel Values
		nUI_INFOMODE_SWF  = 23;
		nUI_INFOPANEL_SWF = "SWF_InfoPanel";
		
		-- Set Up the Panel Data itself
		nUI_InfoPanels[nUI_INFOPANEL_SWF ] =
		{	
			enabled   = true,
			desc      = Translate["Info Panel Text"],             -- player friendly name/description of the panel
			label     = Translate["Info Panel Label"],	       -- label to use on the panel selection button face
			rotation  = nUI_INFOMODE_SWF,            -- index or position this panel appears on/in when clicking the selector button
			full_size = true;                              -- this plugin requires the entire info panel port without the button bag
			
			options  =
			{
				enabled  = true,
			},
		};
		
		SWF_InfoPanel    = CreateFrame( "Frame", nUI_INFOPANEL_SWF, nUI_Dashboard.Anchor );
		SWF_InfoPanel.active   = true;
		
		local function onEvent()
			if event == "VARIABLES_LOADED" then
				if ( nUI_Loaded ) then
					nUI_ResetWatchFrame = function() end;
				end
				if ( not SWF_WatchFrame ) then 
					SWF_WatchFrame = CreateScrollFrame();					
				end
				SWF_InfoPanel.active = true;
			end	
		end
		SWF_InfoPanel:SetScript( "OnEvent", onEvent );
		SWF_InfoPanel:RegisterEvent( "VARIABLES_LOADED" );

		---------------------------------------------------
		-- [v1.01.00] initPanel routine
		---------------------------------------------------
		SWF_InfoPanel.initPanel = function( container, options )
			SWF_InfoPanel.container = container;
			SWF_InfoPanel.options   = options;
			if options and options.enabled then
				SWF_InfoPanel.setEnabled( true );
			end
		end

		---------------------------------------------------
		-- [v1.01.00] sizeChanged routine
		---------------------------------------------------
		SWF_InfoPanel.sizeChanged = function( scale, height, width )
			local options  = SWF_InfoPanel.options;
			local Objectives   = SWF_InfoPanel.Objectives;
			SWF_InfoPanel.scale = scale;
		end	

		---------------------------------------------------
		-- [v1.01.00] Validate Enable Status
		---------------------------------------------------
		SWF_InfoPanel.setEnabled = function( enabled )
			if SWF_InfoPanel.enabled ~= enabled then
				SWF_InfoPanel.enabled = enabled;
				if not enabled then
					local Objectives = SWF_InfoPanel.Objectives;
					if Objectives.saved_parent then
						Objectives:SetParent( Objectives.saved_parent );
						Functions["Default"].SetBackDrop(Objectives,Variables["Default"].BackGround);
						Functions["Default"].SetMovable(Objectives,true);
						Objectives:ClearAllPoints();
						Functions["ScrollFrame"].SetAnchor(Objectives,nil);

					end
				else
					local Objectives = SWF_WatchFrame;
					SWF_InfoPanel.Objectives = Objectives;
					if not Objectives.saved_parent then
						Objectives.saved_parent   = Objectives:GetParent();
					end
					Objectives:SetParent( SWF_InfoPanel.container );
					Objectives:ClearAllPoints();
					Objectives:SetPoint( "BOTTOMRIGHT", SWF_InfoPanel.container, "BOTTOMRIGHT", 0, 0 );
					Objectives:SetPoint( "TOPLEFT", SWF_InfoPanel.container, "TOPLEFT", 0, 0 );
					Objectives:SetFrameStrata( SWF_InfoPanel.container:GetFrameStrata() );
					Objectives:SetFrameLevel( SWF_InfoPanel.container:GetFrameLevel()+1 );
					Functions["Default"].SetBackDrop(Objectives,Variables["InfoPanel"].BackGround);
					Functions["Default"].SetMovable(Objectives,false);					
				end				
			end			
		end

		---------------------------------------------------
		-- [v1.01.00] setSelected routine
		---------------------------------------------------
		SWF_InfoPanel.setSelected = function( selected )
			if selected ~= SWF_InfoPanel.selected then
				SWF_InfoPanel.selected = selected;
				if selected then
				else
				end
			end
		end
		
	end
end

-- If nUI is not loaded or the infopanel system is not being used then create a normal frame 
if ( not nUI_Loaded or not nUI_InfoPanel ) then

	local function DealWith_nUI()
		nUI_Loaded = true;
		nUI_ResetWatchFrame = function() end;
	end

	local function onEvent()
		if event == "PLAYER_ENTERING_WORLD" then		
			if (IsAddOnLoaded("nUI") and not nUI_Loaded) then
				DealWith_nUI();
			end
			SWF_WatchFrame = CreateScrollFrame();
			SWF_EventFrame:UnregisterEvent( "PLAYER_ENTERING_WORLD" );
		end	
	end

	SWF_EventFrame    = CreateFrame( "Frame", "SWF_EventFrame", UIParent );
	SWF_EventFrame:SetScript( "OnEvent", onEvent );
	SWF_EventFrame:RegisterEvent( "PLAYER_ENTERING_WORLD" );
end

