local addonName, addonTable = ...;

addonTable.Common = {};
addonTable.Common.Variables = {};
addonTable.Common.Functions = {};

-- Common Variables used in nearly all addons
addonTable.Common.Variables = {
	
	-- Initial or Stored Anchor for the main Frame
	--Anchor = {	pt = "CENTER", a = UIParent, apt = "CENTER", x = 0, y = 0 },
	MainAnchor = {
		Offset = { Top = 0, Left = 0 },
	},
	
	-- Initial or Stored BackGround data ( Enabled, BackDrop, Colors ) for the main Frame
	BackGround = {
		Enabled = true,
		BackDrop = {       
			bgFile = "Interface/Tooltips/UI-Tooltip-Background", 
			edgeFile = "Interface/Tooltips/UI-Tooltip-Border", 
			tile = true, 
			tileSize = 16, 
			edgeSize = 16, 
			insets = { left = 4, right = 4, top = 4, bottom = 4 }
		},                       
		BackColor = { red=0,green=0,blue=0,alpha=1 },
		BorderColor = { red=255,green=255,blue=0,alpha=1 }
	},
	
	-- Initial or Stored Size Data for the main Frame
	Size = {
		Enabled = true, Width = 500, Height = 200
	},	
	
	-- Initial or Stored Other Data for the main Frame
	Locked = false, Hidden = false 
};

-- Common Functions that can be used in any addon
addonTable.Common.Functions = {

	-- Respond to MouseDown events
	OnMouseDown = function(self)
		if ( ( not self.isLocked ) or ( self.isLocked == 0 ) ) then
			self:StartMoving();
			self.isMoving = true;
			self.hasMoved = false;
		end
	end,
	
	-- Respond to MouseUp events
	OnMouseUp = function(self)
		if ( self.isMoving ) then
			self:StopMovingOrSizing();
			self.isMoving = false;
			self.hasMoved = true;
		end
	end,
	
	-- Respond to Hide Events
	OnHide = function(self)
		if ( self.isMoving ) then
			self:StopMovingOrSizing();
			self.isMoving = false;
		end
	end,
	
	-- Set a BackDrop if enabled
	SetBackDrop = function(self,BackGround)
		local bd = BackGround.BackDrop;
		local bg = BackGround.BackColor;
		local bc = BackGround.BorderColor;
		if ( not BackGround.Enabled ) then
			bd = nil;
			bg = { red = 0, green = 0, blue = 0, alpha = 0 };
			bc = { red = 0, green = 0, blue = 0, alpha = 0 };
		end
		self:SetBackdrop(bd);
		self:SetBackdropColor(bg.red,bg.green,bg.blue, bg.alpha);
		self:SetBackdropBorderColor(bc.red, bc.green,bc.blue, bc.alpha);	
	end,
	
	-- Set Up the size of the Frame
	SetSize = function(self,Size)
		if ( Size.Enabled ) then
			self:SetWidth(Size.Width);
			self:SetHeight(Size.Height);
		end
	end,
	
	-- Set Up the Movable Frame details
	SetMovable = function(self,isMovable)
		if ( isMovable ) then
			self:RegisterForDrag("LeftButton");
			self:EnableMouse(true);
			self:SetMovable(true);
			self:SetScript("OnMouseDown",addonTable.Common.Functions.OnMouseDown);
			self:SetScript("OnMouseUp",addonTable.Common.Functions.OnMouseUp);
			self:SetScript("OnHide",addonTable.Common.Functions.OnHide);
		else
			self:RegisterForDrag(nil);
			self:EnableMouse(false);
			self:SetMovable(false);
			self:SetScript("OnMouseDown",nil);
			self:SetScript("OnMouseUp",nil);
			self:SetScript("OnHide",nil);
		end
	end
};






